==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/ArrayCore/src/HRFKDirectRayleighRadial.cpp <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-07-12
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "HRFKDirectRayleighRadial.h"
#include "FKCrossSpectrum.h"
#include "FKGridSearch.h"
#include "HRFKRayleighEllipticity.h"
#include "FKPower.h"
#include "FKSteeringThreeComponentRayleighRadial.h"

namespace ArrayCore {

  /*!
    \class HRFKDirectRayleighRadial HRFKDirectRayleighRadial.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  double HRFKDirectRayleighRadial::value(const Point& kell, int index) const
  {
    if(isInsideLimits(kell)) {
      FKPower p(&FKSteeringThreeComponentRayleighRadial::cache(_gridCache, index));
      p.setCaponValue(_crossSpectrum->rayleigh());
      return p.value();
    } else {
      return -1.0;
    }
  }

  double HRFKDirectRayleighRadial::value(const Point& kell) const
  {
    if(isInsideLimits(kell)) {
      FKSteeringThreeComponentRayleighRadial * s=static_cast<FKSteeringThreeComponentRayleighRadial *>(_steering);
      double ell=::tan(kell.z());
      s->initValue(kell, ell);
      FKPower p(s);
      p.setCaponValue(_crossSpectrum->rayleigh());
      return p.value();
    } else {
      return -1.0;
    }
  }

  double HRFKDirectRayleighRadial::ellipticity(const Point& kell)
  {
    double ell=::tan(kell.z());
    FKGridSearch grid;
    double ellh, ellz;
    ellh=ell;
    HRFKDirectRayleighVerticalEllipticity * fz;
    fz=new HRFKDirectRayleighVerticalEllipticity(_gridCache);
    grid.setFunction(fz);
    fz->setK(kell);
    grid.setGrid(kell.z()-M_PI/20, kell.z()+M_PI/20, M_PI/40);
    grid.globalMax(0.0);
    ellz=::tan(grid.pos().x());

    APP_LOG(6, tr("  Ellipticities: radial %1 deg, vertical %2 deg\n")
            .arg(Angle::radiansToDegrees(::atan(ellh)))
            .arg(Angle::radiansToDegrees(::atan(ellz))))
    return ellipticityHelper(ellh, ellz);
  }

} // namespace ArrayCore

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/HRFKDirectRayleighRadial.cpp <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-07-12
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "HRFKDirectRayleighRadial.h"
#include "FKCrossSpectrum.h"
#include "FKGridSearch.h"
#include "HRFKRayleighEllipticity.h"
#include "FKPower.h"
#include "FKSteeringThreeComponentRayleighRadial.h"

namespace ArrayCore {

  /*!
    \class HRFKDirectRayleighRadial HRFKDirectRayleighRadial.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  double HRFKDirectRayleighRadial::value(const Point& kell, int index) const
  {
    if(isInsideLimits(kell)) {
      FKPower p(&FKSteeringThreeComponentRayleighRadial::cache(_gridCache, index));
      p.setCaponValue(_crossSpectrum->matrix());
      return p.value();
    } else {
      return -1.0;
    }
  }

  double HRFKDirectRayleighRadial::value(const Point& kell) const
  {
    if(isInsideLimits(kell)) {
      FKSteeringThreeComponentRayleighRadial * s=static_cast<FKSteeringThreeComponentRayleighRadial *>(_steering);
      double ell=::tan(kell.z());
      s->initValue(kell, ell);
      FKPower p(s);
      p.setCaponValue(_crossSpectrum->matrix());
      return p.value();
    } else {
      return -1.0;
    }
  }

  double HRFKDirectRayleighRadial::ellipticity(const Point& kell, bool& ok)
  {
    double ell=::tan(kell.z());
    FKGridSearch grid;
    double ellh, ellz;
    ellh=ell;
    HRFKDirectRayleighVerticalEllipticity * fz;
    fz=new HRFKDirectRayleighVerticalEllipticity(_gridCache);
    grid.setFunction(fz);
    fz->setK(kell);
    grid.setGrid(kell.z()-M_PI/20, kell.z()+M_PI/20, M_PI/40);
    grid.globalMax(0.0);
    ellz=::tan(grid.pos().x());

    APP_LOG(6, tr("  Ellipticities: radial %1 deg, vertical %2 deg\n")
            .arg(Angle::radiansToDegrees(::atan(ellh)))
            .arg(Angle::radiansToDegrees(::atan(ellz))))
    return ellipticityHelper(ellh, ellz, ok);
  }

} // namespace ArrayCore
